hstrat.hstrat.stratum\_retention\_predicates.StratumRetentionPredicateStochastic
================================================================================

.. currentmodule:: hstrat.hstrat.stratum_retention_predicates

.. autoclass:: StratumRetentionPredicateStochastic

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StratumRetentionPredicateStochastic.CalcMrcaUncertaintyUpperBound
      ~StratumRetentionPredicateStochastic.CalcNumStrataRetainedUpperBound
      ~StratumRetentionPredicateStochastic.__init__
   
   

   
   
   